<?php
namespace Ep\WooCommerce;

use Ep\WordPress\Service\AbstractWordPressService;
use Zend\Validator\ValidatorInterface;
use Zend\Validator\ValidatorPluginManager;

/**
 * Class RegistrationService
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class RegistrationService extends AbstractWordPressService
{
	public function attach(): void
	{
		add_action('woocommerce_register_form_start', [$this, 'registerFormBefore']);
	}

	public function attachAdmin(): void
	{
		add_filter('woocommerce_account_settings', [$this, 'accountSettings']);
	}

	/**
	 * Dodaje polje u postavke WooCommerca u tab Računi.
	 *
	 * @param $settings
	 *
	 * @return mixed
	 */
	public function accountSettings($settings)
	{
		$beforeIndex = null;

		foreach ($settings as $index => $setting) {
			if ($setting['type'] === 'sectionend' && $setting['id'] === 'account_registration_options') {
				$beforeIndex = $index;
				break;
			}
		}

		array_splice($settings, $beforeIndex, 0, [[
			'title'       => 'Tekst iznad obrasca za registraciju',
			'desc'        => 'Ovaj tekst će se prikazati na stranici za registraciju, odmah ispod naslova, a iznad sâmog obrasca.',
			'id'          => 'woocommerce_registration_description',
			'css'         => 'width:500px; height: 100px;',
			'type'        => 'textarea',
			'autoload'    => false,
			'desc_tip'    => true,
		]]);

		return $settings;
	}

	public function registerFormBefore()
	{
		if ($text = get_option('woocommerce_registration_description', null)) {
			?>
			<p>
				<?= $text; ?>
			</p>
			<?php
		}
	}
}