<?php
namespace Ep\WordPress\Service;

use Psr\Container\ContainerInterface;
use WP_User;
use Zend\Log\LoggerInterface;
use Zend\View\Renderer\RendererInterface;

/**
 * Defaultna implementacija.
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
abstract class AbstractWordPressService implements WordPressServiceInterface
{
	/** @var ContainerInterface */
	protected $services;
	/** @var RendererInterface */
	protected $renderer;
	/** @var UserService */
	protected $users;
	/** @var LoggerInterface */
	protected $log;

	/**
	 * AbstractWordPressService constructor.
	 *
	 * @param ContainerInterface $container
	 */
	public function __construct(ContainerInterface $container)
	{
		$this->services = $container;
	}

	/**
	 * @return UserService|mixed
	 */
	protected function getUsers()
	{
		if (null === $this->users) {
			$this->users = $this->services->get('WordPressUsers');
		}

		return $this->users;
	}

	/**
	 * Vraća view renderer
	 *
	 * @return RendererInterface
	 */
	protected function getView()
	{
		if (null === $this->renderer) {
			$this->renderer = $this->services->get('twig');
		}
		return $this->renderer;
	}

	/**
	 * @param $template
	 * @param array $vars
	 *
	 * @return string
	 */
	protected function renderView($template, array $vars = [])
	{
		$renderer = $this->getView();
		return $renderer->render($template, $vars);
	}

	/**
	 * @param $key
	 *
	 * @return array
	 */
	protected function getConfig($key = null)
	{
		$config = $this->services->get('config');
		return $key ? $config[$key] ?? [] : $config;
	}

	/**
	 * @return bool
	 */
	protected function hasUser()
	{
		$user = $this->getUser();
		return $user->ID > 0;
	}

	/**
	 * @return WP_User
	 */
	protected function getUser()
	{
		return wp_get_current_user();
	}

	/**
	 * Pokreće se prilikom aktivacije plugina.
	 */
	public function activate(): void
	{ }

	/**
	 * Pokreće se prilikom deaktivacije plugina.
	 */
	public function deactivate(): void
	{ }

	/**
	 * Dodaje handlere na WP akcije i filtere.
	 */
	public function attach(): void
	{ }

	/**
	 * Dodaje front-end resurse.
	 */
	public function assets(): void
	{ }

	/**
	 * Dodaje handlere za akcije i filtere u adminu.
	 */
	public function attachAdmin(): void
	{ }

	/**
	 * Uklanja handlere s WP akcija i filtera.
	 */
	public function detach(): void
	{ }

	/**
	 * Uklanja handlere s akcija i filtera u adminu.
	 */
	public function detachAdmin(): void
	{ }

	/**
	 * Dodaje front-end resurse u adminu.
	 */
	public function adminAssets(): void
	{ }
}