<?php
namespace Ep\WordPress\Service;

use Ep\WordPress\Exception;
use Psr\Container\ContainerInterface;
use WP_Post;

/**
 * Class PostMetadataService
 *
 * @package Ep\WordPress\Service
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class MetadataService extends AbstractWordPressService
{
	/** @var MetadataProviderInterface[] */
	protected $providers = [];

	public function __construct(ContainerInterface $container)
	{
		parent::__construct($container);

		add_filter('the_posts', [$this, 'preloadMetadata'], 10, 1);
		add_filter('get_post_metadata', [$this, 'getPostMetadata'], 10, 3);
	}

	/**
	 * Dodaje handlere na WP akcije i filtere.
	 */
	public function attach(): void
	{

	}

	/**
	 * Dodaje metadata provider u servis.
	 *
	 * @param MetadataProviderInterface $provider
	 */
	public function addProvider(MetadataProviderInterface $provider)
	{
		$this->providers[] = $provider;
	}

	/**
	 * Vraća metapodatak datog posta pod datim ključem.
	 *
	 * @param mixed $metadata
	 * @param int $postId
	 * @param string $metaKey
	 *
	 * @return mixed
	 */
	public function getPostMetadata($metadata, $postId, $metaKey)
	{
		if (null === $metaKey) {
			return $metadata;
		}

		foreach ($this->providers as $provider) {
			if ($provider->hasMetadata($metaKey)) {
				$metadata = $provider->getMetadata($postId, $metaKey, $metadata);
			}
		}

		return $metadata;
	}

	/**
	 * @param WP_Post[]|int[] $posts
	 *
	 * @return array
	 */
	public function preloadMetadata(array $posts)
	{
		try {
			foreach ($this->providers as $provider) {
				$provider->preloadMetadata($posts);
			}
		} catch (Exception\MetadataException $e) {
			throw new Exception\RuntimeException('Došlo je do greške prilikom rada s meta podacima.', 0, $e);
		}

		return $posts;
	}
}